import {
  Body,
  Controller,
  HttpCode,
  Post,
  Req,
  UseGuards,
} from '@nestjs/common';
import { ApiBody, ApiCreatedResponse, ApiTags } from '@nestjs/swagger';
import { SwipesService } from './swipes.service';
import { CreateSwipeDto } from './dto/create-swipe.dto';
import JwtAuthGuard from 'src/auth/guards/jwt-auth.guard';
import { RequestWithUser } from 'src/auth/interfaces/request-with-user.interface';
import { CreateSwipeResponseDto } from './dto/create-swipe.response.dto';

@ApiTags('swipes')
@Controller('swipes')
export class SwipesController {
  constructor(private readonly swipesService: SwipesService) {}

  @HttpCode(201)
  @Post()
  @UseGuards(JwtAuthGuard)
  @ApiBody({ type: CreateSwipeDto })
  @ApiCreatedResponse({ type: CreateSwipeResponseDto })
  async create(
    @Req() req: RequestWithUser,
    @Body() createData: CreateSwipeDto,
  ) {
    const swipe = await this.swipesService.createSwipe(
      req.user.id,
      createData.userId,
      createData.liked,
    );

    return swipe;
  }
}
