import { Injectable } from '@nestjs/common';
import { CreateUserDto } from './dto/create-user.dto';
import { InjectRepository } from '@nestjs/typeorm';
import { User } from './entities/user.entity';
import { In, Not, Repository } from 'typeorm';
import {
  UserEmailNotExistsException,
  UserIdNotExistsException,
} from 'src/utils/errors';

interface GetOptions {
  limit: number;
}

@Injectable()
export class UsersService {
  constructor(
    @InjectRepository(User)
    private usersRepository: Repository<User>,
  ) {}

  async getByEmail(email: string) {
    const user = await this.usersRepository.findOneBy({ email });
    if (!user) {
      throw new UserEmailNotExistsException();
    }
    return user;
  }

  async getById(id: number) {
    const user = await this.usersRepository.findOne({
      where: { id },
      select: { id: true, email: true, name: true, swipes: true, swiped: true },
    });
    if (!user) {
      throw new UserIdNotExistsException();
    }
    return user;
  }

  async getByIds(ids: number[]) {
    return this.usersRepository.findBy({ id: In(ids) });
  }

  async create(userData: CreateUserDto) {
    const user = this.usersRepository.create(userData);
    console.log('user', user);

    await this.usersRepository.save(user);
    return user;
  }

  async get(userId: number, options: GetOptions) {
    // TODO get user preferences

    const user = await this.usersRepository.findBy({ id: userId });
    if (!user) {
      throw new UserIdNotExistsException();
    }

    const users = await this.usersRepository.find({
      where: {
        swiped: {
          sourceUser: {
            id: Not(userId),
          },
        },
      },
      relations: {
        swiped: true,
      },
      take: options.limit || 10,
    });

    return users;
  }
}
